@@ -45,7 +45,6 @@ def sweepAndSave(
                  saveEnable = True,
                  delay = 0.0,
                  plotVars = None,
-                 # plotString  = ['go--','ro-','bo--','o-'], #linePlot: symbol (-; -- or o,s,^,>   plus a colour: 'r' red, 'g' green etc.
                  comments = "No comments provided by user",
                  plotParams = [('go--','linear-linear'),('ro-','linear-linear')]*10,
                  saveCounter = 10,
@@ -54,14 +53,63 @@ def sweepAndSave(
                  plotSize = (10,10),
                  plotAlpha = 0.8,
                     ):
+    """Executes a measurement sweep using pre-defined instruments and parameter values.
+       See usage under https://pypi.org/project/pyneMeas/
 
-    """sweepAndSave is the main function of this module and THE sweepfunction. It is the only function that the user actually calls himlself
-    - all other functions provided here all called 'under the hood by sweepAndsave'. It can be subdivided into three parts:
-    (1): Initialize: Check if user input is valid, create data and log files on disk and set up the plot object. All this is done ONCE ONLY.
-    (2): sweep() function which calls receiver() within: LOOP Section: This is the actual sweep,
-    i.e., iterative process carried out over every single datapoint in the inputArray. This is: (I) set setter Instr to inputArray point, then Query all meas instruments,
-    (II) append data to files and plots and (III) every N-th iteration (default =10), force the file to be written on disk.
-    (3): Wrap-up: Write the final instrument parameters and data to file, save the plot as .png, close all file connections (good practice!)"""
+    Parameters
+    ----------
+        inputDict : dict various value types.
+                    inputDict requires the following keys: 'basePath', 'fileName','setters','sweepArray', 'readers'.
+
+        extraInstruments : list of intrument objects, optional.
+                           Used to keep track of instruments that are not directly used as setter or reader. Default= []
+
+        saveEnable : Boolean, optional.
+                     whether you want to save data to disk. Currently saveEnable = True is required for plotting. Default = True
+
+        delay : float, optional.
+                         Float, wait time in seconds after a value has been set and before instruments are read out. Default = 0.0.
+
+        plotVars : list of (string1,string2) tuples, optional.
+                         list of `('xVar','yVar')` tuples to be plotted. Example: `[ ('V_SD', 'I_SD'),('V_SD', 'I_Leak')]`. Default = None.
+
+        plotParams : list of `('plotString','XAxisScale-YAxisScale')` tuples, optional. Needs to contain one tuple
+                     for each x-y variable pair to be plotted, see above.
+                     `'plotString'` contains color, line and marker info. XAxisScale/YAxisScale can be 'linear' or 'log'.
+                       Example:  [('go-', 'linear-linear')]
+
+        comments : str, optional.
+                Comments written to the .log file. Include information such as sample ID, setup, etc. Default = "No comments provided by user".
+
+        saveCounter : int, optional.
+                After how many datapoints do you want to save data to disc. Can help speed up the measurement slightly. Default = 10.
+
+        breakCondition : tuple, optional.
+                Tuple: ('testVariable',operator,limit). operator can be '>' (greater than) or '<' (lower than).
+                 Example: ('Isd','>',50E-9) breaks the measurement when/if 'Isd' surpasses 50 nA. Default = None.
+
+        plotCounter : int, optional.
+                After how many datapoints do you want to plot the acquired data. plotCounter > 1 can help speed up the measurement significantly
+                since plotting is resource intensive. Default = 1.
+
+        plotSize : tuple of flots/ints, optional.
+                   (sizeX,sizeY) Size of the plot window in cm. Default = (10,10).
+
+        plotAlpha : float, optional.
+                   float ranging from 0 -> 1. Transparency of markers in plot. Default = 0.8.
+    Returns
+    -------
+        df : pandas.DataFrame
+            dataframe object with columns labelled as variable names and one row for each point in the sweepArray.
+
+    """
+    # sweepAndSave is the main function of this module and THE sweepfunction. It is the only function that the user actually calls himlself
+    # - all other functions provided here all called 'under the hood by sweepAndsave'. It can be subdivided into three parts:
+    # (1): Initialize: Check if user input is valid, create data and log files on disk and set up the plot object. All this is done ONCE ONLY.
+    # (2): sweep() function which calls receiver() within: LOOP Section: This is the actual sweep,
+    # i.e., iterative process carried out over every single datapoint in the inputArray. This is: (I) set setter Instr to inputArray point, then Query all meas instruments,
+    # (II) append data to files and plots and (III) every N-th iteration (default =10), force the file to be written on disk.
+    # (3): Wrap-up: Write the final instrument parameters and data to file, save the plot as .png, close all file connections (good practice!)
     # def unpackInputDict(inputDict):
     #     keyList = ['basePath','fileName','inputHeaders','sweepArray',
     #                'inputSetters','outputHeaders','outputReaders']
@@ -535,7 +583,7 @@ def checkInputDict(inputDict,saveEnable):
     #  3. basePath
     assert isinstance(inputDict['basePath'],str), f"The 'basePath' attribute of the input dictionary needs to be a string! You entered {inputDict['basePath']}."
     if os.path.exists(inputDict['basePath']):
-        if saveEnable: print(f'Saving data to existing directory: {inputDict["basePath"]} (if saving is enabled)')
+        if saveEnable: print(f'Saving data to existing directory: {inputDict["basePath"]}')
         else: print('Data not saved to disk. Use pandas.dataFrame return value of sweep() to use data.')
     else:
         os.mkdir(inputDict['basePath'])
